Name:		hatari
Version:	2.5.0
Release:	%mkrel 2
Summary:	An Atari ST emulator suitable for playing games
License:	GPLv2+
Group:		Emulators
URL:		https://hatari.tuxfamily.org/
Source0:	https://download.tuxfamily.org/%{name}/%{version}/%{name}-%{version}.tar.bz2
Patch0:		hatari-2.3.1-mga-i18n+fix-desktop-file.patch
BuildRequires:	cmake
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(portaudio-2.0)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(udev)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(readline)

# Required by zip2st and atari-hd-image
Requires:	unzip
Requires:	mtools
Requires:	dosfstools

%description
Hatari is an emulator for the Atari ST, STE, TT and Falcon computers.

The Atari ST was a 16/32 bit computer system which was first released by
Atari in 1985. Using the Motorola 68000 CPU, it was a very popular computer
having quite a lot of CPU power at that time. Unlike many other Atari ST
emulators which try to give you a good environment for running GEM
applications, Hatari tries to emulate the hardware of a ST as close as
possible so that it is able to run most of the old ST games and demos.


%prep
%autosetup -p1

# Fix interpreter
for pyfile in tools/atari-convert-dir.py tools/debugger/hatari_profile.py tools/hconsole/example.py tools/hconsole/hconsole.py python-ui/hatariui.py python-ui/gentypes.py python-ui/debugui.py
do
  sed -i '1s|/usr/bin/env python3|%{__python3}|' $pyfile
done

%build
%cmake \
	-DDOCDIR:PATH=%{_docdir}/%{name}-%{version} \
	-DBUILD_SHARED_LIBS:BOOL=OFF

%cmake_build


%install
%cmake_install

# fr man pages
install -d -m 755 %{buildroot}/%{_mandir}/fr/man1
install -m 644 doc/fr/%{name}.1 %{buildroot}/%{_mandir}/fr/man1

# appdata file
mkdir -p %{buildroot}%{_datadir}/metainfo
cat > %{buildroot}%{_datadir}/metainfo/%{name}.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright 2014 Ryan Lerch <rlerch@redhat.com> -->
<!--
EmailAddress: hatari-devel@lists.tuxfamily.org
SentUpstream: 2014-09-24
-->
<application>
  <id type="desktop">hatari.desktop</id>
  <metadata_license>CC0-1.0</metadata_license>
  <summary>Atari emulator</summary>
  <description>
    <p>
      Hatari is an emulator that emulates Atari ST, Atari STE, Atari TT and Atari Falcon
      devices.
      It has the ability to emulate the joystick with input from either the host's
      keyboard or joystick.
    </p>
  </description>
  <url type="homepage">https://hatari.tuxfamily.org/</url>
  <screenshots>
    <screenshot type="default">https://hatari.tuxfamily.org/screens/features/deskhigh.png</screenshot>
  </screenshots>
</application>
EOF

%find_lang %{name} --with-man

%files -f %{name}.lang
%doc readme.txt doc/fr/clavier-exemple.txt
%doc tools/hmsa/readme-hmsa.txt
%doc %{_docdir}/%{name}-%{version}
%{_bindir}/*
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/mime/packages/%{name}.xml
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_iconsdir}/hicolor/*/mimetypes/*.png
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_iconsdir}/hicolor/scalable/mimetypes/*.svg
%{_mandir}/man1/*.1*


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 2.5.0-2.mga10
+ Revision: 2222196
- Mageia 10 Mass Rebuild

* Sun Apr 21 2024 daviddavid <daviddavid> 2.5.0-1.mga10
+ Revision: 2060228
- new version: 2.5.0

* Tue Nov 01 2022 ghibo <ghibo> 2.4.1-1.mga9
+ Revision: 1900852
- Update to release 2.4.1

* Mon Aug 08 2022 neoclust <neoclust> 2.4.0-1.mga9
+ Revision: 1876102
- New version 2.4.0

* Fri Apr 01 2022 umeabot <umeabot> 2.3.1-2.mga9
+ Revision: 1838913
- Mageia 9 Mass Rebuild

* Mon Dec 28 2020 daviddavid <daviddavid> 2.3.1-1.mga8
+ Revision: 1664412
- new version: 2.3.1

* Wed Feb 19 2020 umeabot <umeabot> 2.2.1-3.mga8
+ Revision: 1542383
- Mageia 8 Mass Rebuild

* Sat Jan 04 2020 luigiwalser <luigiwalser> 2.2.1-2.mga8
+ Revision: 1476399
- rebuild for readline
+ wally <wally>
- build with new cmake macros

* Fri Mar 01 2019 daviddavid <daviddavid> 2.2.1-1.mga7
+ Revision: 1370946
- new version: 2.2.1

* Thu Feb 07 2019 daviddavid <daviddavid> 2.2.0-1.mga7
+ Revision: 1363764
- new version: 2.2.0

* Sun Sep 23 2018 umeabot <umeabot> 2.1.0-2.mga7
+ Revision: 1298168
- Mageia 7 Mass Rebuild

* Sun Mar 25 2018 daviddavid <daviddavid> 2.1.0-1.mga7
+ Revision: 1212294
- new version: 2.1.0
- move appdata file to metainfo dir

* Tue Jan 02 2018 wally <wally> 2.0.0-2.mga7
+ Revision: 1189440
- rebuild for new readline

* Sun Nov 06 2016 daviddavid <daviddavid> 2.0.0-1.mga6
+ Revision: 1065543
- new version: 2.0.0
- port to SDL2

* Mon Feb 15 2016 umeabot <umeabot> 1.9.0-3.mga6
+ Revision: 960605
- Mageia 6 Mass Rebuild

* Wed Sep 16 2015 daviddavid <daviddavid> 1.9.0-2.mga6
+ Revision: 879719
- improve description and summary (like upstream)

* Fri Sep 11 2015 daviddavid <daviddavid> 1.9.0-1.mga6
+ Revision: 876962
- new version: 1.9.0
- patch0: fix desktop file + french translation
- update file list

* Fri Jun 26 2015 daviddavid <daviddavid> 1.8.0-1.mga6
+ Revision: 844579
- new version: 1.8.0
- update Url and Source Url
- add some requires on unzip, mtools and dosfstools
- fix file-not-utf8
- add a comment key for desktop file
- add from fedora an AppData file for the software center
- use %%find_lang %%{name} --with-man macro
- update file list

* Wed Oct 15 2014 umeabot <umeabot> 1.7.0-4.mga5
+ Revision: 744350
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.7.0-3.mga5
+ Revision: 680086
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 1.7.0-2.mga4
+ Revision: 538667
- Mageia 4 Mass Rebuild

* Tue Oct 01 2013 bersuit <bersuit> 1.7.0-1.mga4
+ Revision: 490162
- Update to new upstream version 1.7.0

* Mon Jun 03 2013 fwang <fwang> 1.6.2-3.mga4
+ Revision: 435957
- rebuild for new libpng

* Sat Jan 12 2013 umeabot <umeabot> 1.6.2-2.mga3
+ Revision: 353115
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Nov 05 2012 bersuit <bersuit> 1.6.2-1.mga3
+ Revision: 314267
- updated to upstream 1.6.2
+ malo <malo>
- fixing desktop file

* Mon Oct 31 2011 dmorgan <dmorgan> 1.5.0-1.mga2
+ Revision: 160239
- imported package hatari


* Fri Jul 29 2011 Andrey Bondrov <abondrov@mandriva.org> 1.5.0-1mdv2012.0
+ Revision: 692294
- Fix BuildRequires
- Fix BuildRequires
- imported package hatari


* Sun Jul 24 2011 Andrey Bondrov <bondrov@math.dvgu.ru> 1.5.0-1mdv2011.0
- 1.5.0
- Import from PLF
- Remove PLF reference

* Thu Dec  2 2010 Guillaume Bedot <littletux@zarb.org> 1.4.0-1plf2011.0
- 1.4.0
- fix build reqs, update patch, files list...

* Sat Sep  5 2009 Guillaume Bedot <littletux@zarb.org> 1.3.1-1plf2010.0
- Release 1.3.1
- Drop string-literal patch
- Add hatariui, new menu item and more doc and tools

* Mon Jan 26 2009 Guillaume Bedot <littletux@zarb.org> 1.2.0-1plf2009.1
- Release 1.2.0
- Fix menu tip
- Add zip2st

* Tue Jan  6 2009 Guillaume Bedot <littletux@zarb.org> 1.1.0-2plf2009.1
- Fix build for cooker

* Tue Jan  6 2009 Guillaume Bedot <littletux@zarb.org> 1.1.0-1plf2009.1
- New release 1.1.0

* Thu Apr 17 2008 Guillaume Bedot <littletux@zarb.org> 1.0.1-1plf2008.1
- 1.0.1

* Wed Mar 19 2008 Guillaume Bedot <littletux@zarb.org> 1.0.0-2plf2008.1
- fix 2007.1 build

* Tue Mar 18 2008 Guillaume Bedot <littletux@zarb.org> 1.0.0-1plf2008.1
- Release 1.0.0, build fixes, icon comment

* Mon May 14 2007 Guillaume Bedot <littletux@zarb.org> 0.95-1plf2008.0
- First PLF package

